@@ -391,19 +391,18 @@ snap_cols_pow2 (GtkAction        *action,
 
 static void
 open_url (GtkWindow *parent,
-          const char *url)
+          const char *uri,
+          guint32 user_time)
 {
-  GError *error = NULL;
   GdkScreen *screen;
-  char *command;
+  GError *error = NULL;
 
-  screen = gtk_widget_get_screen (GTK_WIDGET (parent));
+  if (parent)
+    screen = gtk_widget_get_screen (GTK_WIDGET (parent));
+  else
+    screen = gdk_screen_get_default ();
 
-  command = g_strconcat ("gnome-open ", url, NULL);
-  gdk_spawn_command_line_on_screen (screen, command, &error);
-  g_free (command);
-
-  if (error) {
+  if (!gtk_show_uri (screen, uri, user_time, &error)) {
     show_error_dialog (parent, error);
     g_error_free (error);
   }
@@ -411,7 +410,7 @@ open_url (GtkWindow *parent,
 
 static void
 help_contents (GtkAction *action,
-               GtkWindow *window)
+               GucharmapWindow *window)
 {
   const char *lang;
   char *uri = NULL, *url;
@@ -425,21 +424,24 @@ help_contents (GtkAction *action,
     }
  
     uri = g_build_filename (DATADIR,
-                            "/gnome/help/gucharmap/",
+                            "gnome", "help", "gucharmap",
                             lang,
-                            "/gucharmap.xml",
+                            "gucharmap.xml",
                             NULL);
 					
     if (g_file_test (uri, G_FILE_TEST_EXISTS)) {
       break;
     }
+
+    g_free (uri);
+    uri = NULL;
   }
 
   if (!uri)
     return;
 
   url = g_strconcat ("ghelp://", uri, NULL);
-  open_url (window, url);
+  open_url (GTK_WINDOW (window), url, gtk_get_current_event_time ());
   g_free (url);
 }
 
@@ -448,7 +450,7 @@ about_open_url (GtkAboutDialog *about,
                 const char *link,
                 gpointer data)
 {
-  open_url (GTK_WINDOW (about), link);
+  open_url (GTK_WINDOW (about), link, gtk_get_current_event_time ());
 }
 
 static void
